@@ -1,5 +1,5 @@
 import re
-import log
+from flask_cf_framework import log
 from random import randint
 
 def cors(response, code):
